ToPyArrow

Trait ToPyArrow 

pub trait ToPyArrow {
    const OUTPUT_TYPE: PyStaticExpr = _;

    // Required method
    fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>;
}
Create a new PyArrow object from a arrow-rs type.

Provided Associated Constants

const OUTPUT_TYPE: PyStaticExpr = _

The Python type this conversion produces, as a type hint.

Unlike FromPyArrow::INPUT_TYPE this is exact: the conversion always constructs an instance of the named pyarrow class.

Required Methods

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Convert the implemented type into a Python object without consuming it.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ToPyArrow for ArrayData

Source

const OUTPUT_TYPE: PyStaticExpr

Source

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Source

impl ToPyArrow for DataType

Source

const OUTPUT_TYPE: PyStaticExpr

Source

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Source

impl ToPyArrow for Field

Source

const OUTPUT_TYPE: PyStaticExpr

Source

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Source

impl ToPyArrow for RecordBatch

Source

const OUTPUT_TYPE: PyStaticExpr

Source

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Source

impl ToPyArrow for Schema

Source

const OUTPUT_TYPE: PyStaticExpr

Source

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Source

impl<T: ToPyArrow> ToPyArrow for Vec<T>

Source

const OUTPUT_TYPE: PyStaticExpr

Source

fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>

Implementors