pub trait IntoPyArrow {
const OUTPUT_TYPE: PyStaticExpr = _;
// Required method
fn into_pyarrow<'py>(self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>;
}Expand description
Convert an arrow-rs type into a PyArrow object.
Provided Associated Constants
Sourceconst OUTPUT_TYPE: PyStaticExpr = _
const OUTPUT_TYPE: PyStaticExpr = _
The Python type this conversion produces, as a type hint.
Required Methods
Sourcefn into_pyarrow<'py>(self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
fn into_pyarrow<'py>(self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
Convert the implemented type into a Python object while consuming it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl IntoPyArrow for ArrowArrayStreamReader
Convert a [ArrowArrayStreamReader] into a pyarrow.RecordBatchReader.
impl IntoPyArrow for ArrowArrayStreamReader
Convert a [ArrowArrayStreamReader] into a pyarrow.RecordBatchReader.
const OUTPUT_TYPE: PyStaticExpr
fn into_pyarrow<'py>(self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
Sourceimpl IntoPyArrow for Box<dyn RecordBatchReader + Send>
Convert a [RecordBatchReader] into a pyarrow.RecordBatchReader.
impl IntoPyArrow for Box<dyn RecordBatchReader + Send>
Convert a [RecordBatchReader] into a pyarrow.RecordBatchReader.
const OUTPUT_TYPE: PyStaticExpr
fn into_pyarrow<'py>(self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
Implementors
Sourceimpl IntoPyArrow for Table
Convert a Table into pyarrow.Table.
impl IntoPyArrow for Table
Convert a Table into pyarrow.Table.