IntoPyArrow

Trait IntoPyArrow 

pub trait IntoPyArrow {
    const OUTPUT_TYPE: PyStaticExpr = _;

    // Required method
    fn into_pyarrow(self, py: Python<'_>) -> PyResult<Bound<'_, PyAny>>;
}
Convert an arrow-rs type into a PyArrow object.

Provided Associated Constants

const OUTPUT_TYPE: PyStaticExpr = _

The Python type this conversion produces, as a type hint.

See ToPyArrow::OUTPUT_TYPE.

Required Methods

fn into_pyarrow(self, py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Convert the implemented type into a Python object while consuming it.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoPyArrow for ArrowArrayStreamReader

Convert a ArrowArrayStreamReader into a pyarrow.RecordBatchReader.

Source

impl IntoPyArrow for Box<dyn RecordBatchReader + Send>

Convert a RecordBatchReader into a pyarrow.RecordBatchReader.

Implementors

Source

impl IntoPyArrow for Table

Convert a Table into pyarrow.Table.

Source

impl<T: ToPyArrow> IntoPyArrow for T

Source

const OUTPUT_TYPE: PyStaticExpr = <T as ToPyArrow>::OUTPUT_TYPE