pub trait ToPyArrow {
const OUTPUT_TYPE: PyStaticExpr = _;
// Required method
fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>;
}Expand description
Create a new PyArrow object from a arrow-rs type.
Provided Associated Constants
Sourceconst OUTPUT_TYPE: PyStaticExpr = _
const OUTPUT_TYPE: PyStaticExpr = _
The Python type this conversion produces, as a type hint.
Unlike FromPyArrow::INPUT_TYPE this is exact: the conversion always constructs an
instance of the named pyarrow class.
Required Methods
Sourcefn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
fn to_pyarrow<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyAny>>
Convert the implemented type into a Python object without consuming it.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".